Encode

Trait Encode 

pub trait Encode<'q, DB>
where DB: Database,
{ // Required method fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>; // Provided methods fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>> where Self: Sized { ... } fn produces(&self) -> Option<<DB as Database>::TypeInfo> { ... } fn size_hint(&self) -> usize { ... } }
Encode a single value to be sent to the database.

Required Methods

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Writes the value of self into buf without moving self.

Where possible, make use of encode instead as it can take advantage of re-using memory.

Provided Methods

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where Self: Sized,

Writes the value of self into buf in the expected format for the database.

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

fn size_hint(&self) -> usize

Implementations on Foreign Types

Source

impl Encode<'_, ScyllaDB> for &str

Source

impl Encode<'_, ScyllaDB> for &[&str]

Source

impl Encode<'_, ScyllaDB> for &[&[u8]]

Source

impl Encode<'_, ScyllaDB> for &[Cow<'_, str>]

Source

impl Encode<'_, ScyllaDB> for &[IpAddr]

Source

impl Encode<'_, ScyllaDB> for &[bool]

Source

impl Encode<'_, ScyllaDB> for &[f32]

Source

impl Encode<'_, ScyllaDB> for &[f64]

Source

impl Encode<'_, ScyllaDB> for &[i8]

Source

impl Encode<'_, ScyllaDB> for &[i16]

Source

impl Encode<'_, ScyllaDB> for &[i32]

Source

impl Encode<'_, ScyllaDB> for &[i64]

Source

impl Encode<'_, ScyllaDB> for &[u8]

Source

impl Encode<'_, ScyllaDB> for &[Box<&str>]

Source

impl Encode<'_, ScyllaDB> for &[Box<String>]

Source

impl Encode<'_, ScyllaDB> for &[Rc<&str>]

Source

impl Encode<'_, ScyllaDB> for &[Rc<String>]

Source

impl Encode<'_, ScyllaDB> for &[String]

Source

impl Encode<'_, ScyllaDB> for &[Arc<&str>]

Source

impl Encode<'_, ScyllaDB> for &[Arc<String>]

Source

impl Encode<'_, ScyllaDB> for &[Vec<u8>]

Source

impl Encode<'_, ScyllaDB> for &[CqlDate]

Source

impl Encode<'_, ScyllaDB> for &[CqlDuration]

Source

impl Encode<'_, ScyllaDB> for &[CqlTime]

Source

impl Encode<'_, ScyllaDB> for &[CqlTimestamp]

Source

impl Encode<'_, ScyllaDB> for &[CqlTimeuuid]

Source

impl Encode<'_, ScyllaDB> for &[Uuid]

Source

impl Encode<'_, ScyllaDB> for Cow<'_, str>

Source

impl Encode<'_, ScyllaDB> for IpAddr

Source

impl Encode<'_, ScyllaDB> for bool

Source

impl Encode<'_, ScyllaDB> for f32

Source

impl Encode<'_, ScyllaDB> for f64

Source

impl Encode<'_, ScyllaDB> for i8

Source

impl Encode<'_, ScyllaDB> for i16

Source

impl Encode<'_, ScyllaDB> for i32

Source

impl Encode<'_, ScyllaDB> for i64

Source

impl Encode<'_, ScyllaDB> for Box<&str>

Source

impl Encode<'_, ScyllaDB> for Box<&[&str]>

Source

impl Encode<'_, ScyllaDB> for Box<&[Cow<'_, str>]>

Source

impl Encode<'_, ScyllaDB> for Box<&[Box<&str>]>

Source

impl Encode<'_, ScyllaDB> for Box<&[Box<String>]>

Source

impl Encode<'_, ScyllaDB> for Box<&[Rc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Box<&[Rc<String>]>

Source

impl Encode<'_, ScyllaDB> for Box<&[String]>

Source

impl Encode<'_, ScyllaDB> for Box<&[Arc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Box<&[Arc<String>]>

Source

impl Encode<'_, ScyllaDB> for Box<String>

Source

impl Encode<'_, ScyllaDB> for Box<[&str]>

Source

impl Encode<'_, ScyllaDB> for Box<[Cow<'_, str>]>

Source

impl Encode<'_, ScyllaDB> for Box<[Box<&str>]>

Source

impl Encode<'_, ScyllaDB> for Box<[Box<String>]>

Source

impl Encode<'_, ScyllaDB> for Box<[Rc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Box<[Rc<String>]>

Source

impl Encode<'_, ScyllaDB> for Box<[String]>

Source

impl Encode<'_, ScyllaDB> for Box<[Arc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Box<[Arc<String>]>

Source

impl Encode<'_, ScyllaDB> for Rc<&str>

Source

impl Encode<'_, ScyllaDB> for Rc<&[&str]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[&[u8]]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[Cow<'_, str>]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[u8]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[Box<&str>]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[Box<String>]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[Rc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[Rc<String>]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[String]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[Arc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[Arc<String>]>

Source

impl Encode<'_, ScyllaDB> for Rc<&[Vec<u8>]>

Source

impl Encode<'_, ScyllaDB> for Rc<String>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<&str>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Cow<'_, str>>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<IpAddr>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<bool>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<f32>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<f64>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<i8>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<i16>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<i32>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<i64>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<u8>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Box<&str>>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Box<String>>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Rc<&str>>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Rc<String>>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<String>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Arc<&str>>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Arc<String>>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Vec<u8>>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<CqlDate>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<CqlDuration>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<CqlTime>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<CqlTimestamp>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<CqlTimeuuid>>

Source

impl Encode<'_, ScyllaDB> for Rc<Vec<Uuid>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, IpAddr>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, bool>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, f32>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, f64>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, i8>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, i16>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, i32>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, i64>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, String>>

Source

impl Encode<'_, ScyllaDB> for Rc<HashMap<String, Uuid>>

Source

impl Encode<'_, ScyllaDB> for Rc<[&str]>

Source

impl Encode<'_, ScyllaDB> for Rc<[&[u8]]>

Source

impl Encode<'_, ScyllaDB> for Rc<[Cow<'_, str>]>

Source

impl Encode<'_, ScyllaDB> for Rc<[u8]>

Source

impl Encode<'_, ScyllaDB> for Rc<[Box<&str>]>

Source

impl Encode<'_, ScyllaDB> for Rc<[Box<String>]>

Source

impl Encode<'_, ScyllaDB> for Rc<[Rc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Rc<[Rc<String>]>

Source

impl Encode<'_, ScyllaDB> for Rc<[String]>

Source

impl Encode<'_, ScyllaDB> for Rc<[Arc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Rc<[Arc<String>]>

Source

impl Encode<'_, ScyllaDB> for Rc<[Vec<u8>]>

Source

impl Encode<'_, ScyllaDB> for String

Source

impl Encode<'_, ScyllaDB> for Arc<&str>

Source

impl Encode<'_, ScyllaDB> for Arc<&[&str]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[&[u8]]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[Cow<'_, str>]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[u8]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[Box<&str>]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[Box<String>]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[Rc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[Rc<String>]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[String]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[Arc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[Arc<String>]>

Source

impl Encode<'_, ScyllaDB> for Arc<&[Vec<u8>]>

Source

impl Encode<'_, ScyllaDB> for Arc<String>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<&str>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Cow<'_, str>>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<IpAddr>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<bool>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<f32>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<f64>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<i8>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<i16>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<i32>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<i64>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<u8>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Box<&str>>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Box<String>>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Rc<&str>>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Rc<String>>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<String>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Arc<&str>>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Arc<String>>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Vec<u8>>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<CqlDate>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<CqlDuration>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<CqlTime>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<CqlTimestamp>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<CqlTimeuuid>>

Source

impl Encode<'_, ScyllaDB> for Arc<Vec<Uuid>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, IpAddr>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, bool>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, f32>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, f64>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, i8>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, i16>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, i32>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, i64>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, String>>

Source

impl Encode<'_, ScyllaDB> for Arc<HashMap<String, Uuid>>

Source

impl Encode<'_, ScyllaDB> for Arc<[&str]>

Source

impl Encode<'_, ScyllaDB> for Arc<[&[u8]]>

Source

impl Encode<'_, ScyllaDB> for Arc<[Cow<'_, str>]>

Source

impl Encode<'_, ScyllaDB> for Arc<[u8]>

Source

impl Encode<'_, ScyllaDB> for Arc<[Box<&str>]>

Source

impl Encode<'_, ScyllaDB> for Arc<[Box<String>]>

Source

impl Encode<'_, ScyllaDB> for Arc<[Rc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Arc<[Rc<String>]>

Source

impl Encode<'_, ScyllaDB> for Arc<[String]>

Source

impl Encode<'_, ScyllaDB> for Arc<[Arc<&str>]>

Source

impl Encode<'_, ScyllaDB> for Arc<[Arc<String>]>

Source

impl Encode<'_, ScyllaDB> for Arc<[Vec<u8>]>

Source

impl Encode<'_, ScyllaDB> for Vec<&str>

Source

impl Encode<'_, ScyllaDB> for Vec<Cow<'_, str>>

Source

impl Encode<'_, ScyllaDB> for Vec<IpAddr>

Source

impl Encode<'_, ScyllaDB> for Vec<bool>

Source

impl Encode<'_, ScyllaDB> for Vec<f32>

Source

impl Encode<'_, ScyllaDB> for Vec<f64>

Source

impl Encode<'_, ScyllaDB> for Vec<i8>

Source

impl Encode<'_, ScyllaDB> for Vec<i16>

Source

impl Encode<'_, ScyllaDB> for Vec<i32>

Source

impl Encode<'_, ScyllaDB> for Vec<i64>

Source

impl Encode<'_, ScyllaDB> for Vec<u8>

Source

impl Encode<'_, ScyllaDB> for Vec<Box<&str>>

Source

impl Encode<'_, ScyllaDB> for Vec<Box<String>>

Source

impl Encode<'_, ScyllaDB> for Vec<Rc<&str>>

Source

impl Encode<'_, ScyllaDB> for Vec<Rc<String>>

Source

impl Encode<'_, ScyllaDB> for Vec<String>

Source

impl Encode<'_, ScyllaDB> for Vec<Arc<&str>>

Source

impl Encode<'_, ScyllaDB> for Vec<Arc<String>>

Source

impl Encode<'_, ScyllaDB> for Vec<Vec<u8>>

Source

impl Encode<'_, ScyllaDB> for Vec<CqlDate>

Source

impl Encode<'_, ScyllaDB> for Vec<CqlDuration>

Source

impl Encode<'_, ScyllaDB> for Vec<CqlTime>

Source

impl Encode<'_, ScyllaDB> for Vec<CqlTimestamp>

Source

impl Encode<'_, ScyllaDB> for Vec<CqlTimeuuid>

Source

impl Encode<'_, ScyllaDB> for Vec<Uuid>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, IpAddr>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, bool>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, f32>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, f64>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, i8>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, i16>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, i32>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, i64>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, String>

Source

impl Encode<'_, ScyllaDB> for HashMap<String, Uuid>

Source

impl Encode<'_, ScyllaDB> for CqlDate

Source

impl Encode<'_, ScyllaDB> for CqlDuration

Source

impl Encode<'_, ScyllaDB> for CqlTime

Source

impl Encode<'_, ScyllaDB> for CqlTimestamp

Source

impl Encode<'_, ScyllaDB> for CqlTimeuuid

Source

impl Encode<'_, ScyllaDB> for Uuid

Source

impl Encode<'_, ScyllaDB> for [&str]

Source

impl Encode<'_, ScyllaDB> for [&[u8]]

Source

impl Encode<'_, ScyllaDB> for [Cow<'_, str>]

Source

impl Encode<'_, ScyllaDB> for [IpAddr]

Source

impl Encode<'_, ScyllaDB> for [bool]

Source

impl Encode<'_, ScyllaDB> for [f32]

Source

impl Encode<'_, ScyllaDB> for [f64]

Source

impl Encode<'_, ScyllaDB> for [i8]

Source

impl Encode<'_, ScyllaDB> for [i16]

Source

impl Encode<'_, ScyllaDB> for [i32]

Source

impl Encode<'_, ScyllaDB> for [i64]

Source

impl Encode<'_, ScyllaDB> for [u8]

Source

impl Encode<'_, ScyllaDB> for [Box<&str>]

Source

impl Encode<'_, ScyllaDB> for [Box<String>]

Source

impl Encode<'_, ScyllaDB> for [Rc<&str>]

Source

impl Encode<'_, ScyllaDB> for [Rc<String>]

Source

impl Encode<'_, ScyllaDB> for [String]

Source

impl Encode<'_, ScyllaDB> for [Arc<&str>]

Source

impl Encode<'_, ScyllaDB> for [Arc<String>]

Source

impl Encode<'_, ScyllaDB> for [Vec<u8>]

Source

impl Encode<'_, ScyllaDB> for [CqlDate]

Source

impl Encode<'_, ScyllaDB> for [CqlDuration]

Source

impl Encode<'_, ScyllaDB> for [CqlTime]

Source

impl Encode<'_, ScyllaDB> for [CqlTimestamp]

Source

impl Encode<'_, ScyllaDB> for [CqlTimeuuid]

Source

impl Encode<'_, ScyllaDB> for [Uuid]

Source

impl<'a> Encode<'a, Any> for &'a str

Source

fn encode( self, buf: &mut <Any as Database>::ArgumentBuffer<'a>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where &'a str: Sized,

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'a>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for &'q [u8]

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for bool

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for f32

Source

fn encode_by_ref( &self, buf: &mut AnyArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for f64

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for i16

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for i32

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for i64

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for String

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, Any> for Vec<u8>

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<i8>
where DB: Database, i8: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<i8>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<i16>
where DB: Database, i16: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<i16>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<i32>
where DB: Database, i32: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<i32>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<i64>
where DB: Database, i64: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<i64>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<u8>
where DB: Database, u8: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<u8>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<u16>
where DB: Database, u16: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<u16>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<u32>
where DB: Database, u32: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<u32>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<u64>
where DB: Database, u64: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<u64>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, T> Encode<'q, ScyllaDB> for Option<T>
where T: Encode<'q, ScyllaDB> + Type<ScyllaDB> + 'q,

Source

fn produces(&self) -> Option<<ScyllaDB as Database>::TypeInfo>

Source

fn encode( self, buf: &mut <ScyllaDB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode_by_ref( &self, buf: &mut <ScyllaDB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn size_hint(&self) -> usize

Source

impl<'q, T> Encode<'q, Any> for Option<T>
where T: Encode<'q, Any> + 'q + Type<Any>,

Source

fn encode_by_ref( &self, buf: &mut AnyArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q, T, DB> Encode<'q, DB> for &T
where DB: Database, T: Encode<'q, DB>,

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer<'q>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

fn size_hint(&self) -> usize

Source

impl<'r, T> Encode<'_, ScyllaDB> for &[T]
where T: UserDefinedType<'r> + Clone + 'static,

Source

impl<'r, T> Encode<'_, ScyllaDB> for [T]
where T: UserDefinedType<'r> + Clone + 'static,

Source

impl<'r, T> Encode<'_, ScyllaDB> for Vec<T>
where T: UserDefinedType<'r> + Clone + 'static,

Source

impl<'r, T, const N: usize> Encode<'_, ScyllaDB> for [T; N]
where T: UserDefinedType<'r> + Clone + 'static,

Source

impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T0: SerializeValue + Clone + Send + Sync + 'static, T1: SerializeValue + Clone + Send + Sync + 'static, T2: SerializeValue + Clone + Send + Sync + 'static, T3: SerializeValue + Clone + Send + Sync + 'static, T4: SerializeValue + Clone + Send + Sync + 'static, T5: SerializeValue + Clone + Send + Sync + 'static, T6: SerializeValue + Clone + Send + Sync + 'static, T7: SerializeValue + Clone + Send + Sync + 'static, T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T1: SerializeValue + Clone + Send + Sync + 'static, T2: SerializeValue + Clone + Send + Sync + 'static, T3: SerializeValue + Clone + Send + Sync + 'static, T4: SerializeValue + Clone + Send + Sync + 'static, T5: SerializeValue + Clone + Send + Sync + 'static, T6: SerializeValue + Clone + Send + Sync + 'static, T7: SerializeValue + Clone + Send + Sync + 'static, T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T2: SerializeValue + Clone + Send + Sync + 'static, T3: SerializeValue + Clone + Send + Sync + 'static, T4: SerializeValue + Clone + Send + Sync + 'static, T5: SerializeValue + Clone + Send + Sync + 'static, T6: SerializeValue + Clone + Send + Sync + 'static, T7: SerializeValue + Clone + Send + Sync + 'static, T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T3: SerializeValue + Clone + Send + Sync + 'static, T4: SerializeValue + Clone + Send + Sync + 'static, T5: SerializeValue + Clone + Send + Sync + 'static, T6: SerializeValue + Clone + Send + Sync + 'static, T7: SerializeValue + Clone + Send + Sync + 'static, T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T4: SerializeValue + Clone + Send + Sync + 'static, T5: SerializeValue + Clone + Send + Sync + 'static, T6: SerializeValue + Clone + Send + Sync + 'static, T7: SerializeValue + Clone + Send + Sync + 'static, T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T5: SerializeValue + Clone + Send + Sync + 'static, T6: SerializeValue + Clone + Send + Sync + 'static, T7: SerializeValue + Clone + Send + Sync + 'static, T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T6: SerializeValue + Clone + Send + Sync + 'static, T7: SerializeValue + Clone + Send + Sync + 'static, T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T7, T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T7: SerializeValue + Clone + Send + Sync + 'static, T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T8, T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T8, T9, T10, T11, T12, T13, T14, T15)
where T8: SerializeValue + Clone + Send + Sync + 'static, T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T9, T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T9, T10, T11, T12, T13, T14, T15)
where T9: SerializeValue + Clone + Send + Sync + 'static, T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T10, T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T10, T11, T12, T13, T14, T15)
where T10: SerializeValue + Clone + Send + Sync + 'static, T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T11, T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T11, T12, T13, T14, T15)
where T11: SerializeValue + Clone + Send + Sync + 'static, T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T12, T13, T14, T15> Encode<'_, ScyllaDB> for (T12, T13, T14, T15)
where T12: SerializeValue + Clone + Send + Sync + 'static, T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T13, T14, T15> Encode<'_, ScyllaDB> for (T13, T14, T15)
where T13: SerializeValue + Clone + Send + Sync + 'static, T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T14, T15> Encode<'_, ScyllaDB> for (T14, T15)
where T14: SerializeValue + Clone + Send + Sync + 'static, T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<T15> Encode<'_, ScyllaDB> for (T15,)
where T15: SerializeValue + Clone + Send + Sync + 'static,

Source

impl<const N: usize> Encode<'_, ScyllaDB> for &[[u8; N]]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[&str; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[Cow<'_, str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[Box<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[Box<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[Rc<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[Rc<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[String; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[Arc<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Box<[Arc<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<&[u8; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<&[[u8; N]]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[&str; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[&[u8]; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[Cow<'_, str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[u8; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[Box<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[Box<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[Rc<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[Rc<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[String; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[Arc<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[Arc<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[Vec<u8>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Rc<[[u8; N]]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<&[u8; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<&[[u8; N]]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[&str; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[&[u8]; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[Cow<'_, str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[u8; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[Box<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[Box<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[Rc<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[Rc<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[String; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[Arc<&str>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[Arc<String>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[Vec<u8>; N]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for Arc<[[u8; N]]>

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [&str; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [&[u8]; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Cow<'_, str>; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [IpAddr; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [bool; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [f32; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [f64; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [i8; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [i16; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [i32; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [i64; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [u8; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Box<&str>; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Box<String>; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Rc<&str>; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Rc<String>; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [String; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Arc<&str>; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Arc<String>; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Vec<u8>; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [CqlDate; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [CqlDuration; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [CqlTime; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [CqlTimestamp; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [CqlTimeuuid; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [Uuid; N]

Source

impl<const N: usize> Encode<'_, ScyllaDB> for [[u8; N]]

Source

impl<const N: usize, const M: usize> Encode<'_, ScyllaDB> for Rc<[[u8; N]; M]>

Source

impl<const N: usize, const M: usize> Encode<'_, ScyllaDB> for Arc<[[u8; N]; M]>

Source

impl<const N: usize, const M: usize> Encode<'_, ScyllaDB> for [[u8; N]; M]

Implementors